@@ -6,12 +6,12 @@ from snakebids.app import SnakeBidsApp
 
 def get_parser():
     """Exposes parser for sphinx doc generation, cwd is the docs dir"""
-    app = SnakeBidsApp("../", skip_parse_args=True)
+    app = SnakeBidsApp("../")
     return app.parser
 
 
 def main():
-    app = SnakeBidsApp(Path(__file__).resolve().parents[1])  # to get repository root
+    app = SnakeBidsApp(Path(__file__).resolve().parent)  # to get repository root
     app.run_snakemake()
 
 
